@@ -5,26 +5,26 @@ xlim_user = c(a,b)
 
 y=x$data
 
-theta_all = rep(0, 5)
-theta_all[1:2] = x$theta[1:2]
-theta_all[5] = 1
+tau_all = rep(0, 5)
+tau_all[1:2] = x$tau[1:2]
+tau_all[5] = 1
 
 if (x$type == "s") {
-	gamma_hat = x$parameters$gamma
-	theta_all[3] = gamma_hat
+	gamma_hat = x$theta$gamma
+	tau_all[3] = gamma_hat
 	}
 if (any(x$type == c("h", "hh"))) {
 	delta_hat = x$theta["delta"]
-	theta_all[4] = delta_hat
+	tau_all[4] = delta_hat
 	}
 if (x$method == "IGMM") x$distname = "normal"
-if (x$distname == "normal") x$beta = x$theta[1:2]
+if (x$distname == "normal") x$beta = x$tau[1:2]
 
-#xx_input = get.input(y, theta = theta_all)
+#xx_input = get.input(y, theta = tau_all)
 
 aux.lambert=function(xx){
-if (x$type == "s") return(dLambertW(xx, beta = x$beta, gamma = x$parameters$gamma, distname = x$distname))
-if (any(x$type == c("h", "hh"))) return(dLambertW(xx, beta = x$beta, delta = x$parameters$delta, distname = x$distname))
+if (x$type == "s") return(dLambertW(xx, beta = x$beta, gamma = x$theta$gamma, distname = x$distname))
+if (any(x$type == c("h", "hh"))) return(dLambertW(xx, beta = x$beta, delta = x$theta$delta, distname = x$distname))
 }
 
 aux.compare = function(xx){
@@ -35,8 +35,8 @@ else beta_y = suppressWarnings(fitdistr(y, x$distname)$est)
 return(dLambertW(xx, beta = beta_y, gamma = 0,delta = 0, alpha = 1, distname = x$distname))
 }
 
-x_l=range(y)[1]-0.25*sd(y)
-x_u=range(y)[2]+0.25*sd(y)
+x_l=range(y)[1]-0.2*sd(y)
+x_u=range(y)[2]+0.2*sd(y)
 
 if (!is.null(xlim_user[1])) x_l = xlim_user[1]
 if (!is.null(xlim_user[2])) x_u = xlim_user[2]
@@ -47,12 +47,14 @@ LTY=c(1,1,2)
 
 n=length(y)
 BS = ceiling((range(y)[2]-range(y)[1])/(3.96 * sd(y)*n^(-1/3)))
+#y.window = y[y>a && y<b]
+#BS = ceiling((range(y.window)[2]-range(y.window)[1])/(3.96 * sd(y.window)*n^(-1/3)))
 
 H=hist(y, BS, plot=FALSE)
 D.np=density(y)$y
 D.p=aux.compare(seq(x_l, x_u, length=100))
 S = c(-Inf, Inf)
-if (x$type == "s") S=support(x$theta)
+if (x$type == "s") S=support(x$tau)
 
 sup.l=seq(max(S[1], x_l), min(S[2], x_u), length=100)
 D.pLW=aux.lambert(sup.l[-c(1, length(sup.l))])
@@ -82,15 +84,15 @@ if (x$type == "s"){
 		pos.r="right"
 		leg.txt.r=paste("Lower bound: \n a =",round(S[1],2))
 	}
-	#legend("bottomright", c(as.expression(bquote(gamma == .(round(obj$parameters$gamma,3)))),
-	#leg.txt.r = c(as.expression(bquote(gamma == .(round(x$parameters$gamma,3)))), leg.txt.r)
+	#legend("bottomright", c(as.expression(bquote(gamma == .(round(obj$theta$gamma,3)))),
+	#leg.txt.r = c(as.expression(bquote(gamma == .(round(x$theta$gamma,3)))), leg.txt.r)
 	legend(pos.r, leg.txt.r)
 }
 
 if (QQ) {
 	x11()
-	if (x$type == "s") qqLambertW(y, beta = x$beta, gamma = x$parameters$gamma, distname=x$distname)
-	if (any(x$type == c("h", "hh"))) qqLambertW(y, beta = x$beta, delta = x$parameters$delta, distname=x$distname)
+	if (x$type == "s") qqLambertW(y, beta = x$beta, gamma = x$theta$gamma, distname=x$distname)
+	if (any(x$type == c("h", "hh"))) qqLambertW(y, beta = x$beta, delta = x$theta$delta, distname=x$distname)
 }
 # end of plotting function
 }
