@@ -6,9 +6,9 @@ function(x, ...){
     #cat(x$type)
     #cat("\n")
 
-if (is.null(x$parameters$gamma)) x$parameters$gamma = 0
-if (is.null(x$parameters$delta)) x$parameters$delta = 0
-if (is.null(x$parameters$alpha)) x$parameters$alpha = 1
+if (is.null(x$theta$gamma)) x$theta$gamma = 0
+if (is.null(x$theta$delta)) x$theta$delta = 0
+if (is.null(x$theta$alpha)) x$theta$alpha = 1
     cat(" Input distribution: ")
 distname_input = substr(x$distname, 13, nchar(x$distname))
     cat(distname_input)
@@ -22,14 +22,14 @@ if (x$type =="hh") pre_text = "heavy-tail (two parameters)"
     cat(paste("A", pre_text, x$distname_with_beta))
     #cat("\n")
     cat("\n with parameters:\n")
-    cat(paste(paste(" ", beta_names(distname_input)," = ", sep=""), round(x$parameters$beta,3), sep=""))
+    cat(paste(paste(" ", beta_names(distname_input)," = ", sep=""), round(x$theta$beta,3), sep=""))
     cat("\n")
-    if (x$type == "s") cat(paste(" gamma =", round(x$parameters$gamma,3)))
-    if (x$type == "h") cat(" delta =", round(x$parameters$delta,3))
-    if (x$type == "hh") cat(paste(" ",paste(c("delta_l"," delta_r"),"=", sep=""), round(x$parameters$delta,3), sep="   "))
+    if (x$type == "s") cat(paste(" gamma =", round(x$theta$gamma,3)))
+    if (x$type == "h") cat(" delta =", round(x$theta$delta,3))
+    if (x$type == "hh") cat(paste(" ",paste(c("delta_l"," delta_r"),"=", sep=""), round(x$theta$delta,3), sep="   "))
     cat("\n")
-    if (x$parameters$alpha != 1){
-    cat(paste(" alpha =", round(x$parameters$alpha,3)))
+    if (x$theta$alpha != 1){
+    cat(paste(" alpha =", round(x$theta$alpha,3)))
     cat("\n")
     }
 }
